@@ -1,6 +1,12 @@
 import json
-from smile_id_core.Signature import Signature
-from smile_id_core.Utilities import Utilities
+from typing import Dict
+
+from smile_id_core.Utilities import (
+    Utilities,
+    get_signature,
+    validate_sec_params,
+    sid_server_map,
+)
 from smile_id_core.ServerError import ServerError
 import requests
 
@@ -8,24 +14,26 @@ __all__ = ["IdApi"]
 
 
 class IdApi:
-    timestamp = 0
-    sec_key = ""
-
-    def __init__(self, partner_id, api_key, sid_server):
+    def __init__(self, partner_id: str, api_key: str, sid_server: str or int):
         if not partner_id or not api_key:
             raise ValueError("partner_id or api_key cannot be null or empty")
         self.partner_id = partner_id
         self.api_key = api_key
         if sid_server in [0, 1]:
-            sid_server_map = {
-                0: "https://3eydmgh10d.execute-api.us-west-2.amazonaws.com/test",
-                1: "https://la7am6gdm8.execute-api.us-west-2.amazonaws.com/prod",
-            }
             self.url = sid_server_map[sid_server]
         else:
             self.url = sid_server
 
-    def submit_job(self, partner_params, id_params, use_validation_api=True):
+    def submit_job(
+        self,
+        partner_params: Dict,
+        id_params: Dict,
+        use_validation_api=True,
+        options_params: Dict = None,
+    ):
+        if not options_params:
+            options_params = {}
+
         Utilities.validate_partner_params(partner_params)
 
         if not id_params:
@@ -40,13 +48,10 @@ class IdApi:
                 "Please ensure that you are setting your job_type to 5 to query ID Api"
             )
 
-        sec_key_object = self.__get_sec_key()
-        payload = self.__configure_json(
-            partner_params,
-            id_params,
-            sec_key_object["sec_key"],
-            sec_key_object["timestamp"],
+        sec_key_object = get_signature(
+            self.partner_id, self.api_key, options_params.get("signature")
         )
+        payload = self.__configure_json(partner_params, id_params, sec_key_object)
         response = self.__execute_http(payload)
         if response.status_code != 200:
             raise ServerError(
@@ -56,14 +61,10 @@ class IdApi:
             )
         return response
 
-    def __get_sec_key(self):
-        sec_key_gen = Signature(self.partner_id, self.api_key)
-        return sec_key_gen.generate_sec_key()
-
-    def __configure_json(self, partner_params, id_params, sec_key, timestamp):
+    def __configure_json(self, partner_params, id_params, sec_key):
+        validate_sec_params(sec_key)
         payload = {
-            "sec_key": sec_key,
-            "timestamp": timestamp,
+            **sec_key,
             "partner_id": self.partner_id,
             "partner_params": partner_params,
         }
